@@ -10,7 +10,12 @@ from .command_class import CommandClassInfo, CommandClassInfoDataType
 from .device_class import DeviceClass, DeviceClassDataType
 from .device_config import DeviceConfig, DeviceConfigDataType
 from .endpoint import Endpoint, EndpointDataType
-from .notification import Notification, NotificationDataType
+from .notification import (
+    EntryControlNotification,
+    EntryControlNotificationDataType,
+    NotificationNotification,
+    NotificationNotificationDataType,
+)
 from .value import (
     ConfigurationValue,
     MetaDataType,
@@ -19,6 +24,7 @@ from .value import (
     ValueMetadata,
     ValueNotification,
     _get_value_id_from_dict,
+    _init_value,
 )
 
 if TYPE_CHECKING:
@@ -47,15 +53,17 @@ class NodeDataType(TypedDict, total=False):
     status: int  # 0-4  # required
     deviceClass: DeviceClassDataType
     zwavePlusVersion: int
-    nodeType: int
-    roleType: int
+    zwavePlusNodeType: int
+    zwavePlusRoleType: int
     isListening: bool
-    isFrequentListening: bool
+    isFrequentListening: Union[bool, str]
     isRouting: bool
-    maxBaudRate: int
+    maxDataRate: int
+    supportedDataRates: List[int]
     isSecure: bool
-    isBeaming: bool
-    version: int
+    supportsBeaming: bool
+    supportsSecurity: bool
+    protocolVersion: int
     firmwareVersion: str
     manufacturerId: int
     productId: int
@@ -91,10 +99,7 @@ class Node(EventBase):
         for val in data["values"]:
             value_id = _get_value_id_from_dict(self, val)
             try:
-                if val["commandClass"] == CommandClass.CONFIGURATION:
-                    self.values[value_id] = ConfigurationValue(self, val)
-                else:
-                    self.values[value_id] = Value(self, val)
+                self.values[value_id] = _init_value(self, val)
             except UnparseableValue:
                 # If we can't parse the value, don't store it
                 pass
@@ -156,9 +161,9 @@ class Node(EventBase):
         return self.data.get("isListening")
 
     @property
-    def is_frequent_listening(self) -> Optional[bool]:
+    def is_frequent_listening(self) -> Optional[Union[bool, str]]:
         """Return the is_frequent_listening."""
-        return self.data["isFrequentListening"]
+        return self.data.get("isFrequentListening")
 
     @property
     def is_routing(self) -> Optional[bool]:
@@ -166,9 +171,14 @@ class Node(EventBase):
         return self.data.get("isRouting")
 
     @property
-    def max_baud_rate(self) -> Optional[int]:
-        """Return the max_baud_rate."""
-        return self.data.get("maxBaudRate")
+    def max_data_rate(self) -> Optional[int]:
+        """Return the max_data_rate."""
+        return self.data.get("maxDataRate")
+
+    @property
+    def supported_data_rates(self) -> List[int]:
+        """Return the supported_data_rates."""
+        return self.data.get("supportedDataRates", [])
 
     @property
     def is_secure(self) -> Optional[bool]:
@@ -176,14 +186,19 @@ class Node(EventBase):
         return self.data.get("isSecure")
 
     @property
-    def version(self) -> Optional[int]:
-        """Return the version."""
-        return self.data.get("version")
+    def protocol_version(self) -> Optional[int]:
+        """Return the protocol_version."""
+        return self.data.get("protocolVersion")
 
     @property
-    def is_beaming(self) -> Optional[bool]:
-        """Return the is_beaming."""
-        return self.data.get("isBeaming")
+    def supports_beaming(self) -> Optional[bool]:
+        """Return the supports_beaming."""
+        return self.data.get("supportsBeaming")
+
+    @property
+    def supports_security(self) -> Optional[bool]:
+        """Return the supports_security."""
+        return self.data.get("supportsSecurity")
 
     @property
     def manufacturer_id(self) -> Optional[int]:
@@ -211,14 +226,14 @@ class Node(EventBase):
         return self.data.get("zwavePlusVersion")
 
     @property
-    def node_type(self) -> Optional[int]:
-        """Return the node_type."""
-        return self.data.get("nodeType")
+    def zwave_plus_node_type(self) -> Optional[int]:
+        """Return the zwave_plus_node_type."""
+        return self.data.get("zwavePlusNodeType")
 
     @property
-    def role_type(self) -> Optional[int]:
-        """Return the role_type."""
-        return self.data.get("roleType")
+    def zwave_plus_role_type(self) -> Optional[int]:
+        """Return the zwave_plus_role_type."""
+        return self.data.get("zwavePlusRoleType")
 
     @property
     def name(self) -> Optional[str]:
@@ -310,7 +325,7 @@ class Node(EventBase):
 
         self.emit(event.type, event.data)
 
-    async def _async_send_command(
+    async def async_send_command(
         self,
         cmd: str,
         require_schema: Optional[int] = None,
@@ -352,7 +367,7 @@ class Node(EventBase):
             raise UnwriteableValue
 
         # the value object needs to be send to the server
-        result = await self._async_send_command(
+        result = await self.async_send_command(
             "set_value",
             valueId=val.data,
             value=new_value,
@@ -366,11 +381,11 @@ class Node(EventBase):
 
     async def async_refresh_info(self) -> None:
         """Send refreshInfo command to Node."""
-        await self._async_send_command("refresh_info", wait_for_result=False)
+        await self.async_send_command("refresh_info", wait_for_result=False)
 
     async def async_get_defined_value_ids(self) -> List[Value]:
         """Send getDefinedValueIDs command to Node."""
-        data = await self._async_send_command(
+        data = await self.async_send_command(
             "get_defined_value_ids", wait_for_result=True
         )
 
@@ -378,7 +393,8 @@ class Node(EventBase):
             # We should never reach this code
             raise FailedCommand("Command failed", "failed_command")
         return [
-            Value(self, cast(ValueDataType, valueId)) for valueId in data["valueIds"]
+            _init_value(self, cast(ValueDataType, value_id))
+            for value_id in data["valueIds"]
         ]
 
     async def async_get_value_metadata(self, val: Union[Value, str]) -> ValueMetadata:
@@ -387,21 +403,21 @@ class Node(EventBase):
         if not isinstance(val, Value):
             val = self.values[val]
         # the value object needs to be send to the server
-        data = await self._async_send_command(
+        data = await self.async_send_command(
             "get_value_metadata", valueId=val.data, wait_for_result=True
         )
         return ValueMetadata(cast(MetaDataType, data))
 
     async def async_abort_firmware_update(self) -> None:
         """Send abortFirmwareUpdate command to Node."""
-        await self._async_send_command("abort_firmware_update", wait_for_result=False)
+        await self.async_send_command("abort_firmware_update", wait_for_result=False)
 
     async def async_poll_value(self, val: Union[Value, str]) -> None:
         """Send pollValue command to Node for given value (or value_id)."""
         # a value may be specified as value_id or the value itself
         if not isinstance(val, Value):
             val = self.values[val]
-        await self._async_send_command("poll_value", valueId=val.data, require_schema=1)
+        await self.async_send_command("poll_value", valueId=val.data, require_schema=1)
 
     def handle_wake_up(self, event: Event) -> None:
         """Process a node wake up event."""
@@ -438,13 +454,13 @@ class Node(EventBase):
             value_id = _get_value_id_from_dict(self, value_state)
             value = self.values.get(value_id)
             if value is None:
-                self.values[value_id] = Value(self, value_state)
+                self.values[value_id] = _init_value(self, value_state)
             else:
                 value.update(value_state)
 
     def handle_value_added(self, event: Event) -> None:
         """Process a node value added event."""
-        value = Value(self, event.data["args"])
+        value = _init_value(self, event.data["args"])
         self.values[value.value_id] = event.data["value"] = value
 
     def handle_value_updated(self, event: Event) -> None:
@@ -485,9 +501,14 @@ class Node(EventBase):
 
     def handle_notification(self, event: Event) -> None:
         """Process a node notification event."""
-        event.data["notification"] = Notification(
-            self, cast(NotificationDataType, event.data)
-        )
+        if event.data["ccId"] == CommandClass.NOTIFICATION.value:
+            event.data["notification"] = NotificationNotification(
+                self, cast(NotificationNotificationDataType, event.data)
+            )
+        else:
+            event.data["notification"] = EntryControlNotification(
+                self, cast(EntryControlNotificationDataType, event.data)
+            )
 
     def handle_firmware_update_progress(self, event: Event) -> None:
         """Process a node firmware update progress event."""
