@@ -1,9 +1,9 @@
 """Provide a model for the Z-Wave JS value."""
 from typing import TYPE_CHECKING, Any, Dict, Optional, TypedDict, Union
 
-from ..const import VALUE_UNKNOWN, ConfigurationValueType
+from ..const import VALUE_UNKNOWN, CommandClass, ConfigurationValueType
 from ..event import Event
-from ..util.helpers import is_json_string, parse_buffer, parse_buffer_from_json
+from ..util.helpers import parse_buffer
 
 if TYPE_CHECKING:
     from .node import Node
@@ -23,6 +23,7 @@ class MetaDataType(TypedDict, total=False):
     states: Dict[int, str]
     ccSpecific: Dict[str, Any]
     allowManualEntry: bool
+    valueSize: int
 
 
 class ValueDataType(TypedDict, total=False):
@@ -42,6 +43,15 @@ class ValueDataType(TypedDict, total=False):
     ccVersion: int
 
 
+def _init_value(
+    node: "Node", val: ValueDataType
+) -> Union["Value", "ConfigurationValue"]:
+    """Intialize a Value object from ValueDataType."""
+    if val["commandClass"] == CommandClass.CONFIGURATION:
+        return ConfigurationValue(node, val)
+    return Value(node, val)
+
+
 def _get_value_id_from_dict(node: "Node", val: ValueDataType) -> str:
     """Return ID of value from ValueDataType dict."""
     return get_value_id(
@@ -132,6 +142,11 @@ class ValueMetadata:
         """Return allowManualEntry."""
         return self.data.get("allowManualEntry")
 
+    @property
+    def value_size(self) -> Optional[int]:
+        """Return valueSize."""
+        return self.data.get("valueSize")
+
     def update(self, data: MetaDataType) -> None:
         """Update data."""
         self.data.update(data)
@@ -240,13 +255,8 @@ class Value:
             self._metadata.update(data["metadata"])
 
         # Handle buffer dict and json string in value.
-        # In schema version 1 this is type string,
-        # while in schema version 2 this is type buffer.
-        if self.metadata.type in ("string", "buffer"):
-            if isinstance(self._value, dict):
-                self._value = parse_buffer(self._value)
-            elif is_json_string(self._value):
-                self._value = parse_buffer_from_json(self._value)
+        if self.metadata.type == "buffer":
+            self._value = parse_buffer(self._value)
 
 
 class ValueNotification(Value):
